@@ -7,7 +7,7 @@ use OpenAPI::Client::OpenAI;
 use Archive::Zip;
 use XML::Twig;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 sub get_one_answer_from_new_llm {
     my ($request, $body_builder) = @_;
@@ -107,7 +107,6 @@ sub replace_in_docx{
 		}
 	}
 
-
 	# Save changes
 	open my $fh2, '>:utf8', $xml_file or die "Cannot write to XML file";
 	print $fh2 $doc->toString(1);
@@ -123,61 +122,73 @@ sub replace_in_docx{
 	
 }
 
-
+sub generate_meta_hashref_from_file{
+	my $input_fn = shift;
+	open my $fh, '<:utf8', $input_fn or die "Cannot open file: $!";
+	my %data;
+	while (<$fh>) {
+		chomp;
+		my ($key, $value) = split /:/, $_, 2;
+		next unless defined $key && defined $value;
+		$data{"$key"} = $value;
+	}
+	close $fh;
+	return \%data;
+}
 
 =pod
+    USAGE:
+        use strict;
+        use JSON;
+        use lib '../Business-LetterWriter/lib/';
+        use Business::LetterWriter;
 
+        my $template_href = Business::LetterWriter::get_hashref_from_template_file("./CL_TEMPLATE_DE.txt");
 
-USAGE:
-    use strict;
-    use JSON;
-    use lib '../Business-LetterWriter/lib/';
-    use Business::LetterWriter;
+        my $json = JSON->new->utf8(0)->pretty(1);
+        my $letter_template_json = $json->encode($template_href);
 
-    my $template_href = Business::LetterWriter::get_hashref_from_template_file("./CL_TEMPLATE_DE.txt");
+        my $request 
+            = "Here is a template letter in the JSON format: " . $letter_template_json .
+            " Tailor each part to make the whole letter friendier less formal and very short. Return the tailored version of the letter strictly in JSON format. Do not explain anything." ;
+        my $llm_answer_raw = Business::LetterWriter::get_one_answer_from_new_llm($request);
+        my $template_href = $json->decode($llm_answer_raw);
+        my %parms = (outfn => "outtest.txt");
+        Business::LetterWriter::out_parts($template_href, \%parms);
 
-    my $json = JSON->new->utf8(0)->pretty(1);
-    my $letter_template_json = $json->encode($template_href);
+    USAGE:
+        use strict;
+        use JSON;
+        use lib '../Business-LetterWriter/lib/';
+        use Business::LetterWriter;
 
-    my $request 
-        = "Here is a template letter in the JSON format: " . $letter_template_json .
-        " Tailor each part to make the whole letter friendier less formal and very short. Return the tailored version of the letter strictly in JSON format. Do not explain anything." ;
-    my $llm_answer_raw = Business::LetterWriter::get_one_answer_from_new_llm($request);
-    my $template_href = $json->decode($llm_answer_raw);
-    my %parms = (outfn => "outtest.txt");
-    Business::LetterWriter::out_parts($template_href, \%parms);
+        my $template_href = Business::LetterWriter::get_hashref_from_template_file("./customer_req/LETTER_TEMPLATE_DE.txt");
+        my $json = JSON->new->utf8(0)->pretty(1);
+        my $letter_template_json = $json->encode($template_href);
 
-USAGE:
-    use strict;
-    use JSON;
-    use lib '../Business-LetterWriter/lib/';
-    use Business::LetterWriter;
+        my $customer_req_fn = "./customer_req/requirement_1.txt";
+        open my $customer_req_fh, "<:encoding(UTF-8)", $customer_req_fn;
+        my $customer_req_text = do{local $/; <$customer_req_fh>};
 
-    my $template_href = Business::LetterWriter::get_hashref_from_template_file("./customer_req/LETTER_TEMPLATE_DE.txt");
-    my $json = JSON->new->utf8(0)->pretty(1);
-    my $letter_template_json = $json->encode($template_href);
+        # binmode(STDOUT, ":encoding(UTF-8)");  # stdout is UTF-8
+        # print $customer_req;
+        # exit;
 
-    my $customer_req_fn = "./customer_req/requirement_1.txt";
-    open my $customer_req_fh, "<:encoding(UTF-8)", $customer_req_fn;
-    my $customer_req_text = do{local $/; <$customer_req_fh>};
+        my $request 
+            = "Here is a template letter in the JSON format: " . $letter_template_json .
+            "Here is requirement of the company: " . $customer_req_text .
+            " Tailor each part of the template letter to make the whole letter fit to the customer requirement. Return the tailored version of the letter strictly in JSON format. Do not explain anything." ;
 
-    # binmode(STDOUT, ":encoding(UTF-8)");  # stdout is UTF-8
-    # print $customer_req;
-    # exit;
+        my $llm_answer_raw = Business::LetterWriter::get_one_answer_from_new_llm($request);
 
-    my $request 
-        = "Here is a template letter in the JSON format: " . $letter_template_json .
-        "Here is requirement of the company: " . $customer_req_text .
-        " Tailor each part of the template letter to make the whole letter fit to the customer requirement. Return the tailored version of the letter strictly in JSON format. Do not explain anything." ;
+        my $template_href = $json->decode($llm_answer_raw);
 
-    my $llm_answer_raw = Business::LetterWriter::get_one_answer_from_new_llm($request);
-
-    my $template_href = $json->decode($llm_answer_raw);
-
-    # Business::LetterWriter::out_parts($template_href, {outfn => "TAILORED_VERSION.txt"});
-
-    Business::LetterWriter::replace_in_docx("template.docx", "./my_results.docx", $template_href);
+        # Business::LetterWriter::out_parts($template_href, {outfn => "TAILORED_VERSION.txt"});
+        my $metha_file_path_name = "./bj_applications/Elpro/META.txt";
+        my $address_hashref = Business::LetterWriter::generate_meta_hashref_from_file($metha_file_path_name);
+        my %combined_hash = ( %{$address_hashref} , %{$template_href});
 
+        Business::LetterWriter::replace_in_docx("template.docx", "./my_results.docx", \%combined_hash);
 =cut
 
 1;
